Function rustfix::collect_suggestions
source · pub fn collect_suggestions<S: BuildHasher>(
diagnostic: &Diagnostic,
only: &HashSet<String, S>,
filter: Filter
) -> Option<Suggestion>Expand description
Collects code Suggestions from a single compiler diagnostic line.
only— only diagnostics with code in a set of error codes would be collected.